--- dlls/winealsa.drv/mmdevdrv.c.orig	2012-02-07 00:55:55.000000000 +0200
+++ dlls/winealsa.drv/mmdevdrv.c	2012-02-10 13:14:35.000000000 +0200
@@ -346,10 +346,16 @@ static HRESULT alsa_enum_devices(EDataFl
     snd_pcm_stream_t stream = (flow == eRender ? SND_PCM_STREAM_PLAYBACK :
         SND_PCM_STREAM_CAPTURE);
     int err, card;
+    void **hints, **hint;
+    char *name, *io;
+    const char *filter;
+    WCHAR *nameW;
+    DWORD len;
 
     card = -1;
     *num = 0;
 
+    /* Add default device to zero place to make it (System default) */
     if(alsa_try_open(defname, stream)){
         if(ids && keys){
             *ids = HeapAlloc(GetProcessHeap(), 0, sizeof(defaultW));
@@ -360,6 +366,40 @@ static HRESULT alsa_enum_devices(EDataFl
         ++*num;
     }
 
+    /* Enumerating software devices */
+    if ((err = snd_device_name_hint(-1, "pcm", &hints)) == 0){
+        hint = hints;
+        filter = stream == SND_PCM_STREAM_CAPTURE ? "Input" : "Output";
+        while (*hint != NULL) {
+            name = snd_device_name_get_hint(*hint, "NAME");
+            /* Skip default device because it is already added */
+            /* Skip hw devices, it will be added later */
+            if(strstr(name, ":") == NULL && strcmp(name, "default") != 0){
+                io = snd_device_name_get_hint(*hint, "IOID");
+                if (io == NULL || strcmp(io, filter) == 0){
+                    if(alsa_try_open(name, stream)){
+                        if(ids && keys){
+                            len = MultiByteToWideChar(CP_UNIXCP, 0, name, -1, NULL, 0);
+                            nameW = HeapAlloc(GetProcessHeap(), 0, len * sizeof(WCHAR));
+                            MultiByteToWideChar(CP_UNIXCP, 0, name, -1, nameW, len);
+                            ids[*num] = HeapAlloc(GetProcessHeap(), 0, len * sizeof(WCHAR));
+                            memcpy(ids[*num], nameW, len * sizeof(WCHAR));
+                            keys[*num] = HeapAlloc(GetProcessHeap(), 0, len);
+                            memcpy(keys[*num], name, len);
+                        }
+                        ++*num;
+                    }
+                }
+                free(io);
+            }
+            free(name);
+            hint++;
+        }
+        snd_device_name_free_hint(hints);
+    }else
+        WARN("Unable to enumerate ALSA devices! snd_device_name_hint() returns: %d (%s)\n", err, snd_strerror(err));
+
+    /* Enumerating hardware devices */
     for(err = snd_card_next(&card); card != -1 && err >= 0;
             err = snd_card_next(&card)){
         char cardpath[64];
